smartcard.pcsc.PCSCCardRequest.PCSCCardRequest

# ``smartcard`.`pcsc`.`PCSCCardRequest`.`PCSCCardRequest``

class documentation

`class PCSCCardRequest(AbstractCardRequest):`

View In Hierarchy

PCSC CardRequest class.

Method | `__init__` | Construct new PCSCCardRequest.
Method | `getReaderNames` | Returns the list of PCSC readers on which to wait for cards.
Method | `waitforcard` | Wait for card insertion and returns a card service.
Method | `waitforcardevent` | Wait for card insertion or removal.
Instance Variable | `hcontext` | Undocumented
Instance Variable | `pollinginterval` | Undocumented
Instance Variable | `timeout` | Undocumented

Inherited from `AbstractCardRequest`:

Method | `getReaders` | Returns the list or readers on which to wait for cards.
Instance Variable | `cardServiceClass` | Undocumented
Instance Variable | `cardType` | Undocumented
Instance Variable | `newcardonly` | Undocumented
Instance Variable | `readersAsked` | Undocumented

def __init__(self, newcardonly=False, readers=None, cardType=None, cardServiceClass=None, timeout=1):
overrides `smartcard.AbstractCardRequest.AbstractCardRequest.__init__`

Construct new PCSCCardRequest.

Parameters
newcardonly | if True, request a new card default is False, i.e. accepts cards already inserted
readers | the list of readers to consider for requesting a card default is to consider all readers
cardType | the CardType class to wait for; default is AnyCardType, i.e. the request will returns with new or already inserted cards
cardServiceClass | the specific card service class to create and bind to the card default is to create and bind a PassThruCardService
timeout | the time in seconds we are ready to wait for connecting to the requested card. default is to wait one second to wait forever, set timeout to None

def getReaderNames(self):

Returns the list of PCSC readers on which to wait for cards.

def waitforcard(self):
overrides `smartcard.AbstractCardRequest.AbstractCardRequest.waitforcard`

Wait for card insertion and returns a card service.

def waitforcardevent(self):
overrides `smartcard.AbstractCardRequest.AbstractCardRequest.waitforcardevent`

Wait for card insertion or removal.

hcontext =

Undocumented

pollinginterval: `float` =

Undocumented

timeout =
overrides `smartcard.AbstractCardRequest.AbstractCardRequest.timeout`

Undocumented